<!-- template Pagado -->
<h2>Estatus de tu pago <strong>${{cantidad}}.00 MXN</strong>!</h2>

<h3>Informacion de Pago:</h3>
<p>{{nombre}}</p>
<p>{{cantidad}}</p>
<p>Pagado: {{pagado}}</p>
<p>{{recibo}}</p>